@@ -71,24 +71,6 @@ cerver_create_web = lib.cerver_create_web
 cerver_create_web.argtypes = [c_char_p, c_uint16, c_uint16]
 cerver_create_web.restype = c_void_p
 
-# configuration
-cerver_set_receive_buffer_size = lib.cerver_set_receive_buffer_size
-cerver_set_receive_buffer_size.argtypes = [c_void_p, c_size_t]
-
-cerver_set_thpool_n_threads = lib.cerver_set_thpool_n_threads
-cerver_set_thpool_n_threads.argtypes = [c_void_p, c_uint16]
-
-cerver_set_handler_type = lib.cerver_set_handler_type
-cerver_set_handler_type.argtypes = [c_void_p, c_int]
-
-cerver_set_reusable_address_flags = lib.cerver_set_reusable_address_flags
-cerver_set_reusable_address_flags.argtypes = [c_void_p, c_bool]
-
-# start
-cerver_start = lib.cerver_start
-cerver_start.argtypes = [c_void_p]
-cerver_start.restype = c_uint8
-
 def cerver_initialize (end, print_version = True):
 	"""
 	Function to correctly initialize cerver
@@ -109,6 +91,24 @@ def cerver_initialize (end, print_version = True):
 		cerver_version_print_full ()
 		pycerver_version_print_full ()
 
+# configuration
+cerver_set_receive_buffer_size = lib.cerver_set_receive_buffer_size
+cerver_set_receive_buffer_size.argtypes = [c_void_p, c_size_t]
+
+cerver_set_thpool_n_threads = lib.cerver_set_thpool_n_threads
+cerver_set_thpool_n_threads.argtypes = [c_void_p, c_uint16]
+
+cerver_set_handler_type = lib.cerver_set_handler_type
+cerver_set_handler_type.argtypes = [c_void_p, CerverHandlerType]
+
+cerver_set_reusable_address_flags = lib.cerver_set_reusable_address_flags
+cerver_set_reusable_address_flags.argtypes = [c_void_p, c_bool]
+
+# start
+cerver_start = lib.cerver_start
+cerver_start.argtypes = [c_void_p]
+cerver_start.restype = c_uint8
+
 # end
 cerver_shutdown = lib.cerver_shutdown
 cerver_shutdown.argtypes = [c_void_p]
