@@ -21,7 +21,7 @@ HttpDecodeData = CFUNCTYPE (c_void_p, c_void_p)
 HttpDeleteDecoded = CFUNCTYPE (None, c_void_p)
 
 http_route_create = lib.http_route_create
-http_route_create.argtypes = [c_int, c_char_p, HttpHandler]
+http_route_create.argtypes = [RequestMethod, c_char_p, HttpHandler]
 http_route_create.restype = c_void_p
 
 http_route_set_handler = lib.http_route_set_handler
